==> jc-1.4.0.tar.gz: javax/swing/JFormattedTextField__24FormatterFactoryWrapper.c <==
// class javax.swing.JFormattedTextField$FormatterFactoryWrapper

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class f8132226543fd9aa javax_swing_JFormattedTextField
// @dep_class cdd0ab548279d649 javax_swing_JFormattedTextField__24AbstractFormatter
// @dep_class e3da04f50ec7ee11 javax_swing_JFormattedTextField__24AbstractFormatterFactory
// @dep_class 416a27feaaef0045 javax_swing_JFormattedTextField__24FormatterFactoryWrapper

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_JFormattedTextField
// @dep_header javax_swing_JFormattedTextField__24AbstractFormatter
// @dep_header javax_swing_JFormattedTextField__24FormatterFactoryWrapper

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/JFormattedTextField.h"
#include "javax/swing/JFormattedTextField__24AbstractFormatter.h"
#include "javax/swing/JFormattedTextField__24FormatterFactoryWrapper.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// javax.swing.JFormattedTextField$AbstractFormatter formatter
static _jc_field _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$field_info$formatter = {
	.name=		"formatter",
	.signature=	"Ljavax/swing/JFormattedTextField$AbstractFormatter;",
	.class=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	.type=		&_jc_javax_swing_JFormattedTextField__24AbstractFormatter$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object, refs[-1].javax_swing_JFormattedTextField__24FormatterFactoryWrapper.formatter),
};

// Fields
static _jc_field *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields[] = {
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$field_info$formatter
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(javax.swing.JFormattedTextField$AbstractFormatter)
//

static _jc_linenum _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$_init$e2b2bbb2fb22dc9a[];

static const unsigned char _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$_init$e2b2bbb2fb22dc9a[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$_init$e2b2bbb2fb22dc9a[] = {
	&_jc_javax_swing_JFormattedTextField__24AbstractFormatter$type
};

_jc_method _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$_init$e2b2bbb2fb22dc9a = {
	.name=			"<init>",
	.signature=		"(Ljavax/swing/JFormattedTextField$AbstractFormatter;)V",
	.class=			&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	.param_types=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$_init$e2b2bbb2fb22dc9a,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$_init$e2b2bbb2fb22dc9a,
	.signature_hash=	_JC_JLONG(0xe2b2bbb2fb22dc9a),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$_init$e2b2bbb2fb22dc9a,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$_init$e2b2bbb2fb22dc9a
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JFormattedTextField__24FormatterFactoryWrapper, _init$e2b2bbb2fb22dc9a);

void
_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$_init$e2b2bbb2fb22dc9a(_jc_env *const env, _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *this, _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *param0)
{
	struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *r0;
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(141);				// 0
	_JC_REF_FIELD(env, r0, javax_swing_JFormattedTextField__24FormatterFactoryWrapper, formatter) = r1;
	_JC_LINE_NUMBER(142);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.swing.JFormattedTextField$AbstractFormatter getFormatter(javax.swing.JFormattedTextField)
//

static _jc_linenum _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$getFormatter$05eb5d4d7bcf381f[];

static const unsigned char _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$getFormatter$05eb5d4d7bcf381f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$getFormatter$05eb5d4d7bcf381f[] = {
	&_jc_javax_swing_JFormattedTextField$type
};

_jc_method _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$getFormatter$05eb5d4d7bcf381f = {
	.name=			"getFormatter",
	.signature=		"(Ljavax/swing/JFormattedTextField;)Ljavax/swing/JFormattedTextField$AbstractFormatter;",
	.class=			&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	.param_types=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$getFormatter$05eb5d4d7bcf381f,
	.return_type=		&_jc_javax_swing_JFormattedTextField__24AbstractFormatter$type,
	.param_ptypes=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$getFormatter$05eb5d4d7bcf381f,
	.signature_hash=	_JC_JLONG(0x5eb5d4d7bcf381f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable, javax_swing_JFormattedTextField__24FormatterFactoryWrapper.getFormatter$05eb5d4d7bcf381f) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$getFormatter$05eb5d4d7bcf381f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JFormattedTextField__24FormatterFactoryWrapper, getFormatter$05eb5d4d7bcf381f);

_jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *
_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f(_jc_env *const env, _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *this, _jc_javax_swing_JFormattedTextField$object *param0)
{
	struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *r0;
	struct _jc_javax_swing_JFormattedTextField$object *r1;
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *r2;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(146);				// 0
	r2 = _JC_REF_FIELD(env, r0, javax_swing_JFormattedTextField__24FormatterFactoryWrapper, formatter);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods[] = {
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$_init$e2b2bbb2fb22dc9a,
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$getFormatter$05eb5d4d7bcf381f
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_17[] = {
	&_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_69[] = {
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[17]=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_17,
	[69]=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_69,
	[113]=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/JFormattedTextField",	_JC_JLONG(0xf8132226543fd9aa) },
	{ "javax/swing/JFormattedTextField$AbstractFormatter",	_JC_JLONG(0xcdd0ab548279d649) },
	{ "javax/swing/JFormattedTextField$AbstractFormatterFactory",	_JC_JLONG(0xe3da04f50ec7ee11) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type = {
    .type= {
	.name=			"javax/swing/JFormattedTextField$FormatterFactoryWrapper",
	.superclass=		&_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x416a27feaaef0045),
		.source_file=		"JFormattedTextField.java",
		.instance_size=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs) + sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields) / sizeof(*_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields),
		.fields=		_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields,
		.num_methods=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods) / sizeof(*_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods),
		.methods=		_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods,
		.instanceof_hash_table=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_JFormattedTextField$type,
		.num_class_depends=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends) / sizeof(*_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends),
		.class_depends=		_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_JFormattedTextField__24AbstractFormatterFactory= {
	    .getFormatter$05eb5d4d7bcf381f=			// overridden
		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f,
	},
	.javax_swing_JFormattedTextField__24FormatterFactoryWrapper= {
	    .getFormatter$05eb5d4d7bcf381f=
		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/JFormattedTextField__24FormatterFactoryWrapper.c <==
// class javax.swing.JFormattedTextField$FormatterFactoryWrapper

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 68c1159386e1e800 javax_swing_JFormattedTextField
// @dep_class 483643704e215c9c javax_swing_JFormattedTextField__24AbstractFormatter
// @dep_class e3da04f50ec7ee11 javax_swing_JFormattedTextField__24AbstractFormatterFactory
// @dep_class 416a27feaaef0045 javax_swing_JFormattedTextField__24FormatterFactoryWrapper

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_JFormattedTextField
// @dep_header javax_swing_JFormattedTextField__24AbstractFormatter
// @dep_header javax_swing_JFormattedTextField__24FormatterFactoryWrapper

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/JFormattedTextField.h"
#include "javax/swing/JFormattedTextField__24AbstractFormatter.h"
#include "javax/swing/JFormattedTextField__24FormatterFactoryWrapper.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// javax.swing.JFormattedTextField$AbstractFormatter formatter
static _jc_field _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$field_info$formatter = {
	.name=		"formatter",
	.signature=	"Ljavax/swing/JFormattedTextField$AbstractFormatter;",
	.class=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	.type=		&_jc_javax_swing_JFormattedTextField__24AbstractFormatter$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object, refs[-1].javax_swing_JFormattedTextField__24FormatterFactoryWrapper.formatter),
};

// Fields
static _jc_field *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields[] = {
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$field_info$formatter
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(javax.swing.JFormattedTextField$AbstractFormatter)
//

static _jc_linenum _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$_init$e2b2bbb2fb22dc9a[];

static const unsigned char _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$_init$e2b2bbb2fb22dc9a[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$_init$e2b2bbb2fb22dc9a[] = {
	&_jc_javax_swing_JFormattedTextField__24AbstractFormatter$type
};

_jc_method _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$_init$e2b2bbb2fb22dc9a = {
	.name=			"<init>",
	.signature=		"(Ljavax/swing/JFormattedTextField$AbstractFormatter;)V",
	.class=			&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	.param_types=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$_init$e2b2bbb2fb22dc9a,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$_init$e2b2bbb2fb22dc9a,
	.signature_hash=	_JC_JLONG(0xe2b2bbb2fb22dc9a),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$_init$e2b2bbb2fb22dc9a,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$_init$e2b2bbb2fb22dc9a
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JFormattedTextField__24FormatterFactoryWrapper, _init$e2b2bbb2fb22dc9a);

void _JC_JCNI_ATTR
_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$_init$e2b2bbb2fb22dc9a(_jc_env *const env, _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *this, _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *param0)
{
	struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *r0;
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(141);				// 0
	_JC_REF_FIELD(env, r0, javax_swing_JFormattedTextField__24FormatterFactoryWrapper, formatter) = r1;
	_JC_LINE_NUMBER(142);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.swing.JFormattedTextField$AbstractFormatter getFormatter(javax.swing.JFormattedTextField)
//

static _jc_linenum _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$getFormatter$05eb5d4d7bcf381f[];

static const unsigned char _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$getFormatter$05eb5d4d7bcf381f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$getFormatter$05eb5d4d7bcf381f[] = {
	&_jc_javax_swing_JFormattedTextField$type
};

_jc_method _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$getFormatter$05eb5d4d7bcf381f = {
	.name=			"getFormatter",
	.signature=		"(Ljavax/swing/JFormattedTextField;)Ljavax/swing/JFormattedTextField$AbstractFormatter;",
	.class=			&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	.param_types=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_types$getFormatter$05eb5d4d7bcf381f,
	.return_type=		&_jc_javax_swing_JFormattedTextField__24AbstractFormatter$type,
	.param_ptypes=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$param_ptypes$getFormatter$05eb5d4d7bcf381f,
	.signature_hash=	_JC_JLONG(0x5eb5d4d7bcf381f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtable, javax_swing_JFormattedTextField__24FormatterFactoryWrapper.getFormatter$05eb5d4d7bcf381f) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$linenum_table$getFormatter$05eb5d4d7bcf381f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_JFormattedTextField__24FormatterFactoryWrapper, getFormatter$05eb5d4d7bcf381f);

_jc_javax_swing_JFormattedTextField__24AbstractFormatter$object * _JC_JCNI_ATTR
_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f(_jc_env *const env, _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *this, _jc_javax_swing_JFormattedTextField$object *param0)
{
	struct _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object *r0;
	struct _jc_javax_swing_JFormattedTextField$object *r1;
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *r2;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(146);				// 0
	r2 = _JC_REF_FIELD(env, r0, javax_swing_JFormattedTextField__24FormatterFactoryWrapper, formatter);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods[] = {
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$_init$e2b2bbb2fb22dc9a,
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method_info$getFormatter$05eb5d4d7bcf381f
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_17[] = {
	&_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_69[] = {
	&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[17]=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_17,
	[69]=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_69,
	[101]=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/JFormattedTextField",	_JC_JLONG(0x68c1159386e1e800) },
	{ "javax/swing/JFormattedTextField$AbstractFormatter",	_JC_JLONG(0x483643704e215c9c) },
	{ "javax/swing/JFormattedTextField$AbstractFormatterFactory",	_JC_JLONG(0xe3da04f50ec7ee11) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$vtype _jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$type = {
    .type= {
	.name=			"javax/swing/JFormattedTextField$FormatterFactoryWrapper",
	.superclass=		&_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x416a27feaaef0045),
		.source_file=		"JFormattedTextField.java",
		.instance_size=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$refs) + sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields) / sizeof(*_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields),
		.fields=		_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$fields,
		.num_methods=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods) / sizeof(*_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods),
		.methods=		_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$methods,
		.instanceof_hash_table=	_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$instanceof_hash_table,
		.outer_class=		&_jc_javax_swing_JFormattedTextField$type,
		.num_class_depends=		sizeof(_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends) / sizeof(*_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends),
		.class_depends=		_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_JFormattedTextField__24AbstractFormatterFactory= {
	    .getFormatter$05eb5d4d7bcf381f=			// overridden
		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f,
	},
	.javax_swing_JFormattedTextField__24FormatterFactoryWrapper= {
	    .getFormatter$05eb5d4d7bcf381f=
		&_jc_javax_swing_JFormattedTextField__24FormatterFactoryWrapper$method$getFormatter$05eb5d4d7bcf381f,
	},
    }
};
